==> atlassian_connect_host-0.5.2.tar.gz: lib/host_model.dart <==
library ac_dart.host_model;

import 'package:path/path.dart' as path;
import 'package:option/option.dart';
import 'package:constrain/constrain.dart';
import 'package:shelf_oauth/shelf_oauth.dart' show ClientId;

class AddonHost {
  @NotNull()
  final String key;

  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final Option<String> addonSecret;

  AddonHost(this.key, this.baseUrl, [String addonSecret])
      : this.addonSecret = new Option(addonSecret);
}

enum ProductType { jira, confluence, bitbucket, hipchat }

ProductType productTypeFromLiteral(String literal) => ProductType.values
    .firstWhere((type) => literalForProductType(type) == literal);

String literalForProductType(ProductType type) =>
    type.toString().replaceFirst('ProductType.', '');

class AcHostDetails {
  static const String _consumerInfoPath =
      "/plugins/servlet/oauth/consumer-info";

  @NotNull()
  final String key;

  @NotNull()
  final ProductType productType;

  String get productTypeLiteral => literalForProductType(productType);

  @deprecated
  final String publicKey;

  @NotNull()
  final Uri baseUrl;

  Uri get consumerInfoUrl =>
      Uri.parse(path.join(baseUrl.origin, _consumerInfoPath));

  AcHostDetails(this.key, this.productType, this.publicKey, this.baseUrl);

  AcHostDetails.build(
      {this.key, this.productType, this.publicKey, this.baseUrl});

  String toString() => 'AcHostDetails[$key, $productType, $baseUrl]';

  AcHostDetails.fromJson(Map<String, Object> jsonMap)
      : this(jsonMap['key'], productTypeFromLiteral(jsonMap['productType']),
            jsonMap['publicKey'], Uri.parse(jsonMap['baseUrl']));

  Map toJson() => {
        'key': key,
        'productType': literalForProductType(productType),
        'baseUrl': baseUrl.toString(),
        'publicKey': publicKey
      };
}

class AcHostRegistration {
  @NotNull()
  final int id;

  @NotNull()
  final AcHostDetails hostDetails;

  @NotNull()
  final String sharedSecret;

  ClientId get clientId => new ClientId(hostDetails.key, sharedSecret);

  AcHostRegistration(this.id, this.hostDetails, this.sharedSecret);

  AcHostRegistration.build({this.id, this.hostDetails, this.sharedSecret});

  AcHostRegistration.fromJson(Map<String, Object> jsonMap)
      : this(0, new AcHostDetails.fromJson(jsonMap['hostDetails']),
            jsonMap['sharedSecret']);

  Map toJson() => {
        'id': id,
        'hostDetails': hostDetails.toJson(),
        'sharedSecret': sharedSecret,
      };

  String toString() => 'AcHostRegistration[$id, $hostDetails]';
}

==> atlassian_connect_host-0.5.4.tar.gz: lib/host_model.dart <==
library ac_dart.host_model;

import 'package:path/path.dart' as path;
import 'package:option/option.dart';
import 'package:constrain/constrain.dart';
import 'package:shelf_oauth/shelf_oauth.dart' show ClientId;
import 'package:stuff/stuff.dart';

class AddonHost {
  @NotNull()
  final String key;

  @NotNull()
  final Uri baseUrl;

  @NotNull()
  final Option<String> addonSecret;

  AddonHost(this.key, this.baseUrl, [String addonSecret])
      : this.addonSecret = new Option(addonSecret);
}

enum ProductType { jira, confluence, bitbucket, hipchat }

ProductType productTypeFromLiteral(String literal) => ProductType.values
    .firstWhere((type) => literalForProductType(type) == literal);

String literalForProductType(ProductType type) =>
    type.toString().replaceFirst('ProductType.', '');

class AcHostDetails implements Jsonable {
  static const String _consumerInfoPath =
      "/plugins/servlet/oauth/consumer-info";

  @NotNull()
  final String key;

  @NotNull()
  final ProductType productType;

  String get productTypeLiteral => literalForProductType(productType);

  @deprecated
  final String publicKey;

  @NotNull()
  final Uri baseUrl;

  Uri get consumerInfoUrl =>
      Uri.parse(path.join(baseUrl.origin, _consumerInfoPath));

  AcHostDetails(this.key, this.productType, this.publicKey, this.baseUrl);

  AcHostDetails.build(
      {this.key, this.productType, this.publicKey, this.baseUrl});

  String toString() => 'AcHostDetails[$key, $productType, $baseUrl]';

  AcHostDetails.fromJson(Map<String, Object> jsonMap)
      : this(jsonMap['key'], productTypeFromLiteral(jsonMap['productType']),
            jsonMap['publicKey'], Uri.parse(jsonMap['baseUrl']));

  Map toJson() => (buildJson
    ..add('key', key)
    ..add('productType', productType, (v) => literalForProductType(v))
    ..add('baseUrl', baseUrl)
    ..add('publicKey', publicKey)).json;
}

class AcHostRegistration implements Jsonable {
  @NotNull()
  final int id;

  @NotNull()
  final AcHostDetails hostDetails;

  @NotNull()
  final String sharedSecret;

  ClientId get clientId => new ClientId(hostDetails.key, sharedSecret);

  AcHostRegistration(this.id, this.hostDetails, this.sharedSecret);

  AcHostRegistration.build({this.id, this.hostDetails, this.sharedSecret});

  AcHostRegistration.fromJson(Map<String, Object> jsonMap)
      : this(0, new AcHostDetails.fromJson(jsonMap['hostDetails']),
            jsonMap['sharedSecret']);

  Map toJson() => (buildJson
    ..add('id', id)
    ..add('hostDetails', hostDetails)
    ..add('sharedSecret', sharedSecret)).json;

  String toString() => 'AcHostRegistration[$id, $hostDetails]';
}
